import argparse
from datetime import date
import multiprocessing as mp
import time
from Interpv03 import NetCDFVertInterp, load_stations
import variables_to_interpolate as vti
import os

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument('--expid', required=True)
    parser.add_argument('--start_date', required=True)
    parser.add_argument('--end_date', required=True)
    parser.add_argument('--output_dir', required=True)
    parser.add_argument('--station_file', required=True)
    
    return parser.parse_args()

def process_station(station_data):
    name, lat, lon, args, variables = station_data
    try:
        start = time.time()
        
        interpolator = NetCDFVertInterp(
            args.expid,
            date.fromisoformat(args.start_date),
            date.fromisoformat(args.end_date),
            lat,
            lon
        )
        
        interpolator.save_data(args.output_dir, name, variables)
        
        return f"{name} completada en {time.time()-start:.1f}s"
    except Exception as e:
        return f"ERROR en {name}: {str(e)}"

def main():
    args = parse_args()
    stations = load_stations(args.station_file)
    variables = vti.brown_carbon
    
    # Usa SLURM_CPUS_PER_TASK o todos los cores disponibles
    num_proc = int(os.environ.get('SLURM_CPUS_PER_TASK', mp.cpu_count()))
    
    print(f"Usando {num_proc} procesos (asignados por Slurm)")
    
    tasks = [(name, lat, lon, args, variables) for name, lat, lon in stations]
    
    with mp.Pool(num_proc) as pool:
        results = pool.imap_unordered(process_station, tasks)
        for result in results:
            print(result)

if __name__ == "__main__":
    main()